@@ -3,7 +3,8 @@
 import logging
 
 # from ._settings import settings
-from . import data as db
+from . import database as db
+from . import data
 from . import machinelearning as ml
 from . import tools as tools
 from . import visualization as plot
@@ -12,8 +13,11 @@ try:
     import importlib.metadata as importlib_metadata
 except ModuleNotFoundError:
     import importlib_metadata
-package_name = "lib310"
-__version__ = importlib_metadata.version(package_name)
+try:
+    package_name = "lib310"
+    __version__ = importlib_metadata.version(package_name)
+except:
+    __version__ = 'dev'
 
 # settings.verbosity = logging.INFO
 
@@ -21,5 +25,5 @@ b10_logger = logging.getLogger("lib310")
 b10_logger.propagate = False
 
 __all__ = [
-    'db', 'ml', 'tools', 'plot',
+    'db', 'data', 'ml', 'tools', 'plot',
 ]
